@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the positive/negative sentiment of text
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo;
 use strictures 2;
@@ -14,6 +14,7 @@ use Lingua::EN::Opinion::Negative;
 
 use File::Slurper qw( read_text );
 use Lingua::EN::Sentence qw( get_sentences );
+use Statistics::Lite qw( mean );
 
 
 has file => (
@@ -23,7 +24,7 @@ has file => (
 
 
 has text => (
-      is  => 'ro',
+    is => 'ro',
 );
 
 
@@ -71,6 +72,23 @@ sub analyze {
     $self->scores( \@scores );
 }
 
+
+sub averaged_score {
+    my ( $self, $bins ) = @_;
+
+    $bins ||= 10;
+
+    my @scores = map { $_ } @{ $self->scores };
+
+    my @averaged;
+
+    while ( my @n = splice @scores, 0, $bins ) {
+        push @averaged, mean(@n);
+    }
+
+    return \@averaged;
+}
+
 1;
 
 __END__
@@ -85,7 +103,7 @@ Lingua::EN::Opinion - Measure the positive/negative sentiment of text
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -94,6 +112,7 @@ version 0.02
   $opinion->analyze();
   my $sentences = $opinion->sentences;
   my $scores = $opinion->scores;
+  my $averaged = $opinion->averaged_score(5);
 
 =head1 DESCRIPTION
 
@@ -133,6 +152,19 @@ Create a new C<Lingua::EN::Opinion> object.
 
 Measure the positive/negative sentiment of text.
 
+=head2 averaged_score()
+
+  $averaged = $opinion->averaged_score($bins);
+
+Compute the averaged score given a number of (integer) B<bins> (default: 10).
+
+This reduces the amount of "noise" in the original signal.  As such, it loses
+information detail.
+
+For example, if there are 400 sentences, B<bins> of 10 will result in 40 data
+points.  Each point will be the mean of each successive bin-sized set of points
+in the analyzed score.
+
 =head1 SEE ALSO
 
 L<Moo>
@@ -141,12 +173,10 @@ L<File::Slurper>
 
 L<Lingua::EN::Sentence>
 
+L<Statistics::Lite>
+
 L<https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html#lexicon>
 
-=head1 TO DO
-
-Transform the scores into binned percentages.
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
